/***********************************************************************
ColorSafe 1.0 Beta - http://www.woven-media.com/

A Java 6 Swing application for color testing and conversions from RGB to
hexadecimal data formats and vice versa.

Copyright (C) 2008-2009, Brent Allen Parrish <info@woven-media.com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/
package com.woven_media.colorsafe;

// woven-media.com
import com.woven_media.colorsafe.IPalette;
// util
import java.util.ArrayList;

/**
 * X11Colors creates an <code>java.util.ArrayList</code> of
 * standards-compliant X11 colors for direct invocation.
 *
 * @author  Brent Allen Parrish
 * @version %I%, %G%
 * @since   1.0
 */
public class X11Colors implements IPalette
{
    static ArrayList<String[]> colorList;

    /**
     * Creates a <code>java.util.ArrayList</code> of standards-compliant
     * X11 colors mapped to hexadecimal color equivalents.
     *
     * @return <code>java.util.ArrayList</code> of X11 colors.
     * @see    java.util.ArrayList
     */
    public static ArrayList<String[]> createList()
    {
        colorList = new ArrayList<String[]>();
        colorList.add(new String[] {"White"                ,"FFFFFF"});
        colorList.add(new String[] {"Ivory"                ,"FFFFF0"});
        colorList.add(new String[] {"LightYellow"          ,"FFFFE0"});
        colorList.add(new String[] {"Yellow"               ,"FFFF00"});
        colorList.add(new String[] {"Snow"                 ,"FFFAFA"});
        colorList.add(new String[] {"FloralWhite"          ,"FFFAF0"});
        colorList.add(new String[] {"LemonChiffon"         ,"FFFACD"});
        colorList.add(new String[] {"Cornsilk"             ,"FFF8DC"});
        colorList.add(new String[] {"Seashell"             ,"FFF5EE"});
        colorList.add(new String[] {"LavenderBlush"        ,"FFF0F5"});
        colorList.add(new String[] {"PapayaWhip"           ,"FFEFD5"});
        colorList.add(new String[] {"BlanchedAlmond"       ,"FFEBCD"});
        colorList.add(new String[] {"MistyRose"            ,"FFE4E1"});
        colorList.add(new String[] {"Bisque"               ,"FFE4C4"});
        colorList.add(new String[] {"Moccasin"             ,"FFE4B5"});
        colorList.add(new String[] {"NavajoWhite"          ,"FFDEAD"});
        colorList.add(new String[] {"PeachPuff"            ,"FFDAB9"});
        colorList.add(new String[] {"Gold"                 ,"FFD700"});
        colorList.add(new String[] {"Pink"                 ,"FFC0CB"});
        colorList.add(new String[] {"LightPink"            ,"FFB6C1"});
        colorList.add(new String[] {"Orange"               ,"FFA500"});
        colorList.add(new String[] {"LightSalmon"          ,"FFA07A"});
        colorList.add(new String[] {"DarkOrange"           ,"FF8C00"});
        colorList.add(new String[] {"Coral"                ,"FF7F50"});
        colorList.add(new String[] {"HotPink"              ,"FF69B4"});
        colorList.add(new String[] {"Tomato"               ,"FF6347"});
        colorList.add(new String[] {"OrangeRed"            ,"FF4500"});
        colorList.add(new String[] {"DeepPink"             ,"FF1493"});
        colorList.add(new String[] {"Fuchsia"              ,"FF00FF"});
        colorList.add(new String[] {"Magenta"              ,"FF00FF"});
        colorList.add(new String[] {"Red"                  ,"FF0000"});
        colorList.add(new String[] {"OldLace"              ,"FDF5E6"});
        colorList.add(new String[] {"LightGoldenrodYellow" ,"FAFAD2"});
        colorList.add(new String[] {"Linen"                ,"FAF0E6"});
        colorList.add(new String[] {"AntiqueWhite"         ,"FAEBD7"});
        colorList.add(new String[] {"Salmon"               ,"FA8072"});
        colorList.add(new String[] {"GhostWhite"           ,"F8F8FF"});
        colorList.add(new String[] {"MintCream"            ,"F5FFFA"});
        colorList.add(new String[] {"WhiteSmoke"           ,"F5F5F5"});
        colorList.add(new String[] {"Beige"                ,"F5F5DC"});
        colorList.add(new String[] {"Wheat"                ,"F5DEB3"});
        colorList.add(new String[] {"SandyBrown"           ,"F4A460"});
        colorList.add(new String[] {"Azure"                ,"F0FFFF"});
        colorList.add(new String[] {"Honeydew"             ,"F0FFF0"});
        colorList.add(new String[] {"AliceBlue"            ,"F0F8FF"});
        colorList.add(new String[] {"Khaki"                ,"F0E68C"});
        colorList.add(new String[] {"LightCoral"           ,"F08080"});
        colorList.add(new String[] {"PaleGoldenrod"        ,"EEE8AA"});
        colorList.add(new String[] {"Violet"               ,"EE82EE"});
        colorList.add(new String[] {"DarkSalmon"           ,"E9967A"});
        colorList.add(new String[] {"Lavender"             ,"E6E6FA"});
        colorList.add(new String[] {"LightCyan"            ,"E0FFFF"});
        colorList.add(new String[] {"BurlyWood"            ,"DEB887"});
        colorList.add(new String[] {"Plum"                 ,"DDA0DD"});
        colorList.add(new String[] {"Gainsboro"            ,"DCDCDC"});
        colorList.add(new String[] {"Crimson"              ,"DC143C"});
        colorList.add(new String[] {"PaleVioletRed"        ,"DB7093"});
        colorList.add(new String[] {"Goldenrod"            ,"DAA520"});
        colorList.add(new String[] {"Orchid"               ,"DA70D6"});
        colorList.add(new String[] {"Thistle"              ,"D8BFD8"});
        colorList.add(new String[] {"LightGrey"            ,"D3D3D3"});
        colorList.add(new String[] {"Tan"                  ,"D2B48C"});
        colorList.add(new String[] {"Chocolate"            ,"D2691E"});
        colorList.add(new String[] {"Peru"                 ,"CD853F"});
        colorList.add(new String[] {"IndianRed"            ,"CD5C5C"});
        colorList.add(new String[] {"MediumVioletRed"      ,"C71585"});
        colorList.add(new String[] {"Silver"               ,"C0C0C0"});
        colorList.add(new String[] {"DarkKhaki"            ,"BDB76B"});
        colorList.add(new String[] {"RosyBrown"            ,"BC8F8F"});
        colorList.add(new String[] {"MediumOrchid"         ,"BA55D3"});
        colorList.add(new String[] {"DarkGoldenrod"        ,"B8860B"});
        colorList.add(new String[] {"FireBrick"            ,"B22222"});
        colorList.add(new String[] {"PowderBlue"           ,"B0E0E6"});
        colorList.add(new String[] {"LightSteelBlue"       ,"B0C4DE"});
        colorList.add(new String[] {"PaleTurquoise"        ,"AFEEEE"});
        colorList.add(new String[] {"GreenYellow"          ,"ADFF2F"});
        colorList.add(new String[] {"LightBlue"            ,"ADD8E6"});
        colorList.add(new String[] {"DarkGray"             ,"A9A9A9"});
        colorList.add(new String[] {"Brown"                ,"A52A2A"});
        colorList.add(new String[] {"Sienna"               ,"A0522D"});
        colorList.add(new String[] {"YellowGreen"          ,"9ACD32"});
        colorList.add(new String[] {"DarkOrchid"           ,"9932CC"});
        colorList.add(new String[] {"PaleGreen"            ,"98FB98"});
        colorList.add(new String[] {"DarkViolet"           ,"9400D3"});
        colorList.add(new String[] {"MediumPurple"         ,"9370DB"});
        colorList.add(new String[] {"LightGreen"           ,"90EE90"});
        colorList.add(new String[] {"DarkSeaGreen"         ,"8FBC8F"});
        colorList.add(new String[] {"SaddleBrown"          ,"8B4513"});
        colorList.add(new String[] {"DarkMagenta"          ,"8B008B"});
        colorList.add(new String[] {"DarkRed"              ,"8B0000"});
        colorList.add(new String[] {"BlueViolet"           ,"8A2BE2"});
        colorList.add(new String[] {"LightSkyBlue"         ,"87CEFA"});
        colorList.add(new String[] {"SkyBlue"              ,"87CEEB"});
        colorList.add(new String[] {"Gray"                 ,"808080"});
        colorList.add(new String[] {"Olive"                ,"808000"});
        colorList.add(new String[] {"Purple"               ,"800080"});
        colorList.add(new String[] {"Maroon"               ,"800000"});
        colorList.add(new String[] {"Aquamarine"           ,"7FFFD4"});
        colorList.add(new String[] {"Chartreuse"           ,"7FFF00"});
        colorList.add(new String[] {"LawnGreen"            ,"7CFC00"});
        colorList.add(new String[] {"MediumSlateBlue"      ,"7B68EE"});
        colorList.add(new String[] {"LightSlateGray"       ,"778899"});
        colorList.add(new String[] {"SlateGray"            ,"708090"});
        colorList.add(new String[] {"OliveDrab"            ,"6B8E23"});
        colorList.add(new String[] {"SlateBlue"            ,"6A5ACD"});
        colorList.add(new String[] {"DimGray"              ,"696969"});
        colorList.add(new String[] {"MediumAquamarine"     ,"66CDAA"});
        colorList.add(new String[] {"CornflowerBlue"       ,"6495ED"});
        colorList.add(new String[] {"CadetBlue"            ,"5F9EA0"});
        colorList.add(new String[] {"DarkOliveGreen"       ,"556B2F"});
        colorList.add(new String[] {"Indigo"               ,"4B0082"});
        colorList.add(new String[] {"MediumTurquoise"      ,"48D1CC"});
        colorList.add(new String[] {"DarkSlateBlue"        ,"483D8B"});
        colorList.add(new String[] {"SteelBlue"            ,"4682B4"});
        colorList.add(new String[] {"RoyalBlue"            ,"4169E1"});
        colorList.add(new String[] {"Turquoise"            ,"40E0D0"});
        colorList.add(new String[] {"MediumSeaGreen"       ,"3CB371"});
        colorList.add(new String[] {"LimeGreen"            ,"32CD32"});
        colorList.add(new String[] {"DarkSlateGray"        ,"2F4F4F"});
        colorList.add(new String[] {"SeaGreen"             ,"2E8B57"});
        colorList.add(new String[] {"ForestGreen"          ,"228B22"});
        colorList.add(new String[] {"LightSeaGreen"        ,"20B2AA"});
        colorList.add(new String[] {"DodgerBlue"           ,"1E90FF"});
        colorList.add(new String[] {"MidnightBlue"         ,"191970"});
        colorList.add(new String[] {"Aqua"                 ,"00FFFF"});
        colorList.add(new String[] {"Cyan"                 ,"00FFFF"});
        colorList.add(new String[] {"SpringGreen"          ,"00FF7F"});
        colorList.add(new String[] {"Lime"                 ,"00FF00"});
        colorList.add(new String[] {"MediumSpringGreen"    ,"00FA9A"});
        colorList.add(new String[] {"DarkTurquoise"        ,"00CED1"});
        colorList.add(new String[] {"DeepSkyBlue"          ,"00BFFF"});
        colorList.add(new String[] {"DarkCyan"             ,"008B8B"});
        colorList.add(new String[] {"Teal"                 ,"008080"});
        colorList.add(new String[] {"Green"                ,"008000"});
        colorList.add(new String[] {"DarkGreen"            ,"006400"});
        colorList.add(new String[] {"Blue"                 ,"0000FF"});
        colorList.add(new String[] {"MediumBlue"           ,"0000CD"});
        colorList.add(new String[] {"DarkBlue"             ,"00008B"});
        colorList.add(new String[] {"Navy"                 ,"000080"});
        colorList.add(new String[] {"Black"                ,"000000"});
        return colorList;
    } // end list

} // End class












